#!/usr/bin/env python3

#  Copyright (C) 2023 ASTRON (Netherlands Institute for Radio Astronomy)
#  SPDX-License-Identifier: Apache-2.0

import os

file_dir = os.path.dirname(os.path.realpath(__file__))

clean_dir = os.path.join(file_dir, "source", "source_documentation")
print(f"Cleaning.. {clean_dir}/*")

if not os.path.exists(clean_dir):
    exit()

for file_name in os.listdir(clean_dir):
    file = os.path.join(clean_dir, file_name)

    if file_name == "index.rst":
        continue

    print(f"Removing.. {file}")
    os.remove(file)



#!/usr/bin/env python3

#  Copyright (C) 2023 ASTRON (Netherlands Institute for Radio Astronomy)
#  SPDX-License-Identifier: Apache-2.0

import os
import glob
from importlib import resources
from grpc_tools import protoc

proto_dir = os.path.join(os.getcwd(), "proto")
print(f"Compiling proto files in dir {proto_dir}...")

if not os.path.exists(proto_dir):
    exit(-1)

files = glob.glob('./**/*.proto', recursive=True)

proto_file_name = (resources.files("grpc_tools") / "_proto").resolve()
for file in files:
    print(f"Process {file}")
    protoc.main([
        '-c', '-Ilofar_sid/interface=proto', f'-I{proto_file_name}', '--python_out=.', '--pyi_out=.', '--grpc_python_out=.', file
    ])

print("Complete")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/statistics.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/statistics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3lofar_sid/interface/stationcontrol/statistics.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"J\n\rFrequencyBand\x12\x14\n\x0c\x61ntenna_type\x18\x01 \x01(\t\x12\r\n\x05\x63lock\x18\x02 \x01(\x05\x12\x14\n\x0cnyquist_zone\x18\x03 \x01(\x05\"C\n\nBstRequest\x12\x15\n\rantenna_field\x18\x01 \x01(\t\x12\x13\n\x06maxage\x18\x02 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_maxage\"\xf0\x01\n\tBstResult\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x0e\x66requency_band\x18\x02 \x01(\x0b\x32\x0e.FrequencyBand\x12\x1c\n\x14integration_interval\x18\x03 \x01(\x02\x12\'\n\x08\x62\x65\x61mlets\x18\x04 \x03(\x0b\x32\x15.BstResult.BstBeamlet\x1a\x45\n\nBstBeamlet\x12\x0f\n\x07\x62\x65\x61mlet\x18\x01 \x01(\x05\x12\x12\n\nx_power_db\x18\x02 \x01(\x02\x12\x12\n\ny_power_db\x18\x03 \x01(\x02\"&\n\x08\x42stReply\x12\x1a\n\x06result\x18\x03 \x01(\x0b\x32\n.BstResult\"C\n\nSstRequest\x12\x15\n\rantenna_field\x18\x01 \x01(\t\x12\x13\n\x06maxage\x18\x02 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_maxage\"\xd7\x02\n\tSstResult\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x0e\x66requency_band\x18\x02 \x01(\x0b\x32\x0e.FrequencyBand\x12\x1c\n\x14integration_interval\x18\x03 \x01(\x02\x12\'\n\x08subbands\x18\x04 \x03(\x0b\x32\x15.SstResult.SstSubband\x1a\xab\x01\n\nSstSubband\x12\x0f\n\x07subband\x18\x01 \x01(\x05\x12\x11\n\tfrequency\x18\x02 \x01(\x02\x12\x32\n\x08\x61ntennas\x18\x03 \x03(\x0b\x32 .SstResult.SstSubband.SstAntenna\x1a\x45\n\nSstAntenna\x12\x0f\n\x07\x61ntenna\x18\x01 \x01(\x05\x12\x12\n\nx_power_db\x18\x02 \x01(\x02\x12\x12\n\ny_power_db\x18\x03 \x01(\x02\"&\n\x08SstReply\x12\x1a\n\x06result\x18\x03 \x01(\x0b\x32\n.SstResult\"C\n\nXstRequest\x12\x15\n\rantenna_field\x18\x01 \x01(\t\x12\x13\n\x06maxage\x18\x02 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_maxage\"\xe4\x03\n\tXstResult\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x0e\x66requency_band\x18\x02 \x01(\x0b\x32\x0e.FrequencyBand\x12\x1c\n\x14integration_interval\x18\x03 \x01(\x02\x12\x0f\n\x07subband\x18\x04 \x01(\x05\x12\x11\n\tfrequency\x18\x05 \x01(\x02\x12)\n\tbaselines\x18\x06 \x03(\x0b\x32\x16.XstResult.XstBaseline\x1a\x92\x02\n\x0bXstBaseline\x12\x10\n\x08\x61ntenna1\x18\x01 \x01(\x05\x12\x10\n\x08\x61ntenna2\x18\x02 \x01(\x05\x12+\n\x02xx\x18\x03 \x01(\x0b\x32\x1f.XstResult.XstBaseline.XstValue\x12+\n\x02xy\x18\x04 \x01(\x0b\x32\x1f.XstResult.XstBaseline.XstValue\x12+\n\x02yx\x18\x05 \x01(\x0b\x32\x1f.XstResult.XstBaseline.XstValue\x12+\n\x02yy\x18\x06 \x01(\x0b\x32\x1f.XstResult.XstBaseline.XstValue\x1a+\n\x08XstValue\x12\x10\n\x08power_db\x18\x01 \x01(\x02\x12\r\n\x05phase\x18\x02 \x01(\x02\"&\n\x08XstReply\x12\x1a\n\x06result\x18\x03 \x01(\x0b\x32\n.XstResult2o\n\nStatistics\x12\x1f\n\x03\x42st\x12\x0b.BstRequest\x1a\t.BstReply\"\x00\x12\x1f\n\x03Sst\x12\x0b.SstRequest\x1a\t.SstReply\"\x00\x12\x1f\n\x03Xst\x12\x0b.XstRequest\x1a\t.XstReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.statistics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FREQUENCYBAND']._serialized_start=88
  _globals['_FREQUENCYBAND']._serialized_end=162
  _globals['_BSTREQUEST']._serialized_start=164
  _globals['_BSTREQUEST']._serialized_end=231
  _globals['_BSTRESULT']._serialized_start=234
  _globals['_BSTRESULT']._serialized_end=474
  _globals['_BSTRESULT_BSTBEAMLET']._serialized_start=405
  _globals['_BSTRESULT_BSTBEAMLET']._serialized_end=474
  _globals['_BSTREPLY']._serialized_start=476
  _globals['_BSTREPLY']._serialized_end=514
  _globals['_SSTREQUEST']._serialized_start=516
  _globals['_SSTREQUEST']._serialized_end=583
  _globals['_SSTRESULT']._serialized_start=586
  _globals['_SSTRESULT']._serialized_end=929
  _globals['_SSTRESULT_SSTSUBBAND']._serialized_start=758
  _globals['_SSTRESULT_SSTSUBBAND']._serialized_end=929
  _globals['_SSTRESULT_SSTSUBBAND_SSTANTENNA']._serialized_start=860
  _globals['_SSTRESULT_SSTSUBBAND_SSTANTENNA']._serialized_end=929
  _globals['_SSTREPLY']._serialized_start=931
  _globals['_SSTREPLY']._serialized_end=969
  _globals['_XSTREQUEST']._serialized_start=971
  _globals['_XSTREQUEST']._serialized_end=1038
  _globals['_XSTRESULT']._serialized_start=1041
  _globals['_XSTRESULT']._serialized_end=1525
  _globals['_XSTRESULT_XSTBASELINE']._serialized_start=1251
  _globals['_XSTRESULT_XSTBASELINE']._serialized_end=1525
  _globals['_XSTRESULT_XSTBASELINE_XSTVALUE']._serialized_start=1482
  _globals['_XSTRESULT_XSTBASELINE_XSTVALUE']._serialized_end=1525
  _globals['_XSTREPLY']._serialized_start=1527
  _globals['_XSTREPLY']._serialized_end=1565
  _globals['_STATISTICS']._serialized_start=1567
  _globals['_STATISTICS']._serialized_end=1678
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/antennafield.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/antennafield.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5lofar_sid/interface/stationcontrol/antennafield.proto\"2\n\x16\x41ntennafieldIdentifier\x12\x18\n\x10\x61ntenna_field_id\x18\x01 \x01(\t\"w\n\x16SetAntennafieldRequest\x12+\n\nidentifier\x18\x01 \x01(\x0b\x32\x17.AntennafieldIdentifier\x12\x30\n\x0cpower_status\x18\x02 \x01(\x0e\x32\x1a.Antennafield_Power_Status\"E\n\x16GetAntennafieldRequest\x12+\n\nidentifier\x18\x01 \x01(\x0b\x32\x17.AntennafieldIdentifier\"s\n\x12\x41ntennafieldResult\x12+\n\nidentifier\x18\x01 \x01(\x0b\x32\x17.AntennafieldIdentifier\x12\x30\n\x0cpower_status\x18\x02 \x01(\x0e\x32\x1a.Antennafield_Power_Status\"\\\n\x11\x41ntennafieldReply\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\texception\x18\x02 \x01(\t\x12#\n\x06result\x18\x03 \x01(\x0b\x32\x13.AntennafieldResult*R\n\x19\x41ntennafield_Power_Status\x12\x1a\n\x16\x41ntennafield_POWER_OFF\x10\x00\x12\x19\n\x15\x41ntennafield_POWER_ON\x10\x01\x32\x9c\x01\n\x0c\x41ntennafield\x12\x45\n\x14GetAntennafieldPower\x12\x17.GetAntennafieldRequest\x1a\x12.AntennafieldReply\"\x00\x12\x45\n\x14SetAntennafieldPower\x12\x17.SetAntennafieldRequest\x1a\x12.AntennafieldReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.antennafield_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANTENNAFIELD_POWER_STATUS']._serialized_start=512
  _globals['_ANTENNAFIELD_POWER_STATUS']._serialized_end=594
  _globals['_ANTENNAFIELDIDENTIFIER']._serialized_start=57
  _globals['_ANTENNAFIELDIDENTIFIER']._serialized_end=107
  _globals['_SETANTENNAFIELDREQUEST']._serialized_start=109
  _globals['_SETANTENNAFIELDREQUEST']._serialized_end=228
  _globals['_GETANTENNAFIELDREQUEST']._serialized_start=230
  _globals['_GETANTENNAFIELDREQUEST']._serialized_end=299
  _globals['_ANTENNAFIELDRESULT']._serialized_start=301
  _globals['_ANTENNAFIELDRESULT']._serialized_end=416
  _globals['_ANTENNAFIELDREPLY']._serialized_start=418
  _globals['_ANTENNAFIELDREPLY']._serialized_end=510
  _globals['_ANTENNAFIELD']._serialized_start=597
  _globals['_ANTENNAFIELD']._serialized_end=753
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Antenna_Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OK: _ClassVar[Antenna_Status]
    SUSPICIOUS: _ClassVar[Antenna_Status]
    BROKEN: _ClassVar[Antenna_Status]
    BEYOND_REPAIR: _ClassVar[Antenna_Status]
    NOT_AVAILABLE: _ClassVar[Antenna_Status]

class Antenna_Use(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AUTO: _ClassVar[Antenna_Use]
    ON: _ClassVar[Antenna_Use]
    OFF: _ClassVar[Antenna_Use]
OK: Antenna_Status
SUSPICIOUS: Antenna_Status
BROKEN: Antenna_Status
BEYOND_REPAIR: Antenna_Status
NOT_AVAILABLE: Antenna_Status
AUTO: Antenna_Use
ON: Antenna_Use
OFF: Antenna_Use

class Identifier(_message.Message):
    __slots__ = ("antennafield_name", "antenna_name")
    ANTENNAFIELD_NAME_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_NAME_FIELD_NUMBER: _ClassVar[int]
    antennafield_name: str
    antenna_name: str
    def __init__(self, antennafield_name: _Optional[str] = ..., antenna_name: _Optional[str] = ...) -> None: ...

class SetAntennaStatusRequest(_message.Message):
    __slots__ = ("identifier", "antenna_status")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_STATUS_FIELD_NUMBER: _ClassVar[int]
    identifier: Identifier
    antenna_status: Antenna_Status
    def __init__(self, identifier: _Optional[_Union[Identifier, _Mapping]] = ..., antenna_status: _Optional[_Union[Antenna_Status, str]] = ...) -> None: ...

class GetAntennaRequest(_message.Message):
    __slots__ = ("identifier",)
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    identifier: Identifier
    def __init__(self, identifier: _Optional[_Union[Identifier, _Mapping]] = ...) -> None: ...

class SetAntennaUseRequest(_message.Message):
    __slots__ = ("identifier", "antenna_use")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_USE_FIELD_NUMBER: _ClassVar[int]
    identifier: Identifier
    antenna_use: Antenna_Use
    def __init__(self, identifier: _Optional[_Union[Identifier, _Mapping]] = ..., antenna_use: _Optional[_Union[Antenna_Use, str]] = ...) -> None: ...

class AntennaResult(_message.Message):
    __slots__ = ("identifier", "antenna_use", "antenna_status")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_USE_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_STATUS_FIELD_NUMBER: _ClassVar[int]
    identifier: Identifier
    antenna_use: Antenna_Use
    antenna_status: Antenna_Status
    def __init__(self, identifier: _Optional[_Union[Identifier, _Mapping]] = ..., antenna_use: _Optional[_Union[Antenna_Use, str]] = ..., antenna_status: _Optional[_Union[Antenna_Status, str]] = ...) -> None: ...

class AntennaReply(_message.Message):
    __slots__ = ("success", "exception", "result")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    EXCEPTION_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    exception: str
    result: AntennaResult
    def __init__(self, success: bool = ..., exception: _Optional[str] = ..., result: _Optional[_Union[AntennaResult, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/antenna.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/antenna.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0lofar_sid/interface/stationcontrol/antenna.proto\"=\n\nIdentifier\x12\x19\n\x11\x61ntennafield_name\x18\x01 \x01(\t\x12\x14\n\x0c\x61ntenna_name\x18\x02 \x01(\t\"c\n\x17SetAntennaStatusRequest\x12\x1f\n\nidentifier\x18\x01 \x01(\x0b\x32\x0b.Identifier\x12\'\n\x0e\x61ntenna_status\x18\x02 \x01(\x0e\x32\x0f.Antenna_Status\"4\n\x11GetAntennaRequest\x12\x1f\n\nidentifier\x18\x01 \x01(\x0b\x32\x0b.Identifier\"Z\n\x14SetAntennaUseRequest\x12\x1f\n\nidentifier\x18\x01 \x01(\x0b\x32\x0b.Identifier\x12!\n\x0b\x61ntenna_use\x18\x02 \x01(\x0e\x32\x0c.Antenna_Use\"|\n\rAntennaResult\x12\x1f\n\nidentifier\x18\x01 \x01(\x0b\x32\x0b.Identifier\x12!\n\x0b\x61ntenna_use\x18\x02 \x01(\x0e\x32\x0c.Antenna_Use\x12\'\n\x0e\x61ntenna_status\x18\x03 \x01(\x0e\x32\x0f.Antenna_Status\"R\n\x0c\x41ntennaReply\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\texception\x18\x02 \x01(\t\x12\x1e\n\x06result\x18\x03 \x01(\x0b\x32\x0e.AntennaResult*Z\n\x0e\x41ntenna_Status\x12\x06\n\x02OK\x10\x00\x12\x0e\n\nSUSPICIOUS\x10\x01\x12\n\n\x06\x42ROKEN\x10\x02\x12\x11\n\rBEYOND_REPAIR\x10\x03\x12\x11\n\rNOT_AVAILABLE\x10\x04*(\n\x0b\x41ntenna_Use\x12\x08\n\x04\x41UTO\x10\x00\x12\x06\n\x02ON\x10\x01\x12\x07\n\x03OFF\x10\x02\x32\xb4\x01\n\x07\x41ntenna\x12\x31\n\nGetAntenna\x12\x12.GetAntennaRequest\x1a\r.AntennaReply\"\x00\x12=\n\x10SetAntennaStatus\x12\x18.SetAntennaStatusRequest\x1a\r.AntennaReply\"\x00\x12\x37\n\rSetAntennaUse\x12\x15.SetAntennaUseRequest\x1a\r.AntennaReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.antenna_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANTENNA_STATUS']._serialized_start=572
  _globals['_ANTENNA_STATUS']._serialized_end=662
  _globals['_ANTENNA_USE']._serialized_start=664
  _globals['_ANTENNA_USE']._serialized_end=704
  _globals['_IDENTIFIER']._serialized_start=52
  _globals['_IDENTIFIER']._serialized_end=113
  _globals['_SETANTENNASTATUSREQUEST']._serialized_start=115
  _globals['_SETANTENNASTATUSREQUEST']._serialized_end=214
  _globals['_GETANTENNAREQUEST']._serialized_start=216
  _globals['_GETANTENNAREQUEST']._serialized_end=268
  _globals['_SETANTENNAUSEREQUEST']._serialized_start=270
  _globals['_SETANTENNAUSEREQUEST']._serialized_end=360
  _globals['_ANTENNARESULT']._serialized_start=362
  _globals['_ANTENNARESULT']._serialized_end=486
  _globals['_ANTENNAREPLY']._serialized_start=488
  _globals['_ANTENNAREPLY']._serialized_end=570
  _globals['_ANTENNA']._serialized_start=707
  _globals['_ANTENNA']._serialized_end=887
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/observation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/observation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4lofar_sid/interface/stationcontrol/observation.proto\"0\n\x17StartObservationRequest\x12\x15\n\rconfiguration\x18\x01 \x01(\t\"0\n\x16StopObservationRequest\x12\x16\n\x0eobservation_id\x18\x01 \x01(\x03\"6\n\x10ObservationReply\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\texception\x18\x02 \x01(\t2\x91\x01\n\x0bObservation\x12\x41\n\x10StartObservation\x12\x18.StartObservationRequest\x1a\x11.ObservationReply\"\x00\x12?\n\x0fStopObservation\x12\x17.StopObservationRequest\x1a\x11.ObservationReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.observation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STARTOBSERVATIONREQUEST']._serialized_start=56
  _globals['_STARTOBSERVATIONREQUEST']._serialized_end=104
  _globals['_STOPOBSERVATIONREQUEST']._serialized_start=106
  _globals['_STOPOBSERVATIONREQUEST']._serialized_end=154
  _globals['_OBSERVATIONREPLY']._serialized_start=156
  _globals['_OBSERVATIONREPLY']._serialized_end=210
  _globals['_OBSERVATION']._serialized_start=213
  _globals['_OBSERVATION']._serialized_end=358
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from lofar_sid.interface.stationcontrol import station_pb2 as lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in lofar_sid/interface/stationcontrol/station_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class StationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStationState = channel.unary_unary(
                '/station_control.station.Station/GetStationState',
                request_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.GetStationStateRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
                _registered_method=True)
        self.SetStationState = channel.unary_stream(
                '/station_control.station.Station/SetStationState',
                request_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SetStationStateRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
                _registered_method=True)
        self.SoftStationReset = channel.unary_stream(
                '/station_control.station.Station/SoftStationReset',
                request_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SoftStationResetRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
                _registered_method=True)
        self.HardStationReset = channel.unary_stream(
                '/station_control.station.Station/HardStationReset',
                request_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.HardStationResetRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
                _registered_method=True)


class StationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetStationState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetStationState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SoftStationReset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HardStationReset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetStationState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStationState,
                    request_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.GetStationStateRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.SerializeToString,
            ),
            'SetStationState': grpc.unary_stream_rpc_method_handler(
                    servicer.SetStationState,
                    request_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SetStationStateRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.SerializeToString,
            ),
            'SoftStationReset': grpc.unary_stream_rpc_method_handler(
                    servicer.SoftStationReset,
                    request_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SoftStationResetRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.SerializeToString,
            ),
            'HardStationReset': grpc.unary_stream_rpc_method_handler(
                    servicer.HardStationReset,
                    request_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.HardStationResetRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'station_control.station.Station', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('station_control.station.Station', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Station(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetStationState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/station_control.station.Station/GetStationState',
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.GetStationStateRequest.SerializeToString,
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetStationState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/station_control.station.Station/SetStationState',
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SetStationStateRequest.SerializeToString,
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SoftStationReset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/station_control.station.Station/SoftStationReset',
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SoftStationResetRequest.SerializeToString,
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HardStationReset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/station_control.station.Station/HardStationReset',
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.HardStationResetRequest.SerializeToString,
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/opah/grafana-apiv3.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/opah/grafana-apiv3.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,lofar_sid/interface/opah/grafana-apiv3.proto\x12\tgrafanav3\x1a\x1fgoogle/protobuf/timestamp.proto\"N\n\x12ListMetricsRequest\x12(\n\ndimensions\x18\x01 \x03(\x0b\x32\x14.grafanav3.Dimension\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\"z\n\x13ListMetricsResponse\x12\x36\n\x07Metrics\x18\x01 \x03(\x0b\x32%.grafanav3.ListMetricsResponse.Metric\x1a+\n\x06Metric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x9e\x02\n\x15GetMetricValueRequest\x12(\n\ndimensions\x18\x01 \x03(\x0b\x32\x14.grafanav3.Dimension\x12\x0f\n\x07metrics\x18\x02 \x03(\t\x12>\n\x07options\x18\x03 \x03(\x0b\x32-.grafanav3.GetMetricValueRequest.OptionsEntry\x12-\n\tstartDate\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndDate\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n\x16GetMetricValueResponse\x12\x37\n\x06\x66rames\x18\x01 \x03(\x0b\x32\'.grafanav3.GetMetricValueResponse.Frame\x1a\x97\x01\n\x05\x46rame\x12\x0e\n\x06metric\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x1b.grafanav3.SingleValueField\x12\"\n\x04meta\x18\x04 \x01(\x0b\x32\x14.grafanav3.FrameMeta\"\xa1\x02\n\x11GetOptionsRequest\x12\x39\n\tqueryType\x18\x01 \x01(\x0e\x32&.grafanav3.GetOptionsRequest.QueryType\x12J\n\x0fselectedOptions\x18\x02 \x03(\x0b\x32\x31.grafanav3.GetOptionsRequest.SelectedOptionsEntry\x1a\x36\n\x14SelectedOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\tQueryType\x12\x14\n\x10GetMetricHistory\x10\x00\x12\x12\n\x0eGetMetricValue\x10\x01\x12\x16\n\x12GetMetricAggregate\x10\x02\"L\n\tEnumValue\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x04 \x01(\x08\"\xb9\x01\n\x06Option\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.grafanav3.Option.Type\x12(\n\nenumValues\x18\x04 \x03(\x0b\x32\x14.grafanav3.EnumValue\x12\x10\n\x08required\x18\x05 \x01(\x08\x12\r\n\x05label\x18\x06 \x01(\t\"\x1d\n\x04Type\x12\x08\n\x04\x45num\x10\x00\x12\x0b\n\x07\x42oolean\x10\x01\"8\n\x12GetOptionsResponse\x12\"\n\x07options\x18\x01 \x03(\x0b\x32\x11.grafanav3.Option\"\x92\x03\n\x19GetMetricAggregateRequest\x12(\n\ndimensions\x18\x01 \x03(\x0b\x32\x14.grafanav3.Dimension\x12\x0f\n\x07metrics\x18\x02 \x03(\t\x12-\n\tstartDate\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndDate\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08maxItems\x18\x06 \x01(\x03\x12-\n\x0ctimeOrdering\x18\x07 \x01(\x0e\x32\x17.grafanav3.TimeOrdering\x12\x15\n\rstartingToken\x18\x08 \x01(\t\x12\x12\n\nintervalMs\x18\t \x01(\x03\x12\x42\n\x07options\x18\n \x03(\x0b\x32\x31.grafanav3.GetMetricAggregateRequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x1aGetMetricAggregateResponse\x12 \n\x06\x66rames\x18\x01 \x03(\x0b\x32\x10.grafanav3.Frame\x12\x11\n\tnextToken\x18\x02 \x01(\t\"\xfa\x02\n\x17GetMetricHistoryRequest\x12(\n\ndimensions\x18\x03 \x03(\x0b\x32\x14.grafanav3.Dimension\x12\x0f\n\x07metrics\x18\x04 \x03(\t\x12-\n\tstartDate\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndDate\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08maxItems\x18\x07 \x01(\x03\x12-\n\x0ctimeOrdering\x18\x08 \x01(\x0e\x32\x17.grafanav3.TimeOrdering\x12\x15\n\rstartingToken\x18\t \x01(\t\x12@\n\x07options\x18\n \x03(\x0b\x32/.grafanav3.GetMetricHistoryRequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x18GetMetricHistoryResponse\x12 \n\x06\x66rames\x18\x01 \x03(\x0b\x32\x10.grafanav3.Frame\x12\x11\n\tnextToken\x18\x02 \x01(\t\"#\n\x05Label\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x80\x01\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x06labels\x18\x02 \x03(\x0b\x32\x10.grafanav3.Label\x12!\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x11.grafanav3.config\x12\x0e\n\x06values\x18\x04 \x03(\x01\x12\x14\n\x0cstringValues\x18\x05 \x03(\t\"T\n\x0cValueMapping\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x01\x12\n\n\x02to\x18\x02 \x01(\x01\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\r\n\x05\x63olor\x18\x05 \x01(\t\"A\n\x06\x63onfig\x12\x0c\n\x04unit\x18\x01 \x01(\t\x12)\n\x08Mappings\x18\x02 \x03(\x0b\x32\x17.grafanav3.ValueMapping\"\x89\x01\n\x10SingleValueField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x06labels\x18\x02 \x03(\x0b\x32\x10.grafanav3.Label\x12!\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x11.grafanav3.config\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x13\n\x0bstringValue\x18\x05 \x01(\t\"\x8d\x01\n\x05\x46rame\x12\x0e\n\x06metric\x18\x01 \x01(\t\x12.\n\ntimestamps\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x06\x66ields\x18\x03 \x03(\x0b\x32\x10.grafanav3.Field\x12\"\n\x04meta\x18\x04 \x01(\x0b\x32\x14.grafanav3.FrameMeta\"\xcf\x06\n\tFrameMeta\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.grafanav3.FrameMeta.FrameType\x12,\n\x07Notices\x18\x06 \x03(\x0b\x32\x1b.grafanav3.FrameMeta.Notice\x12<\n\x16PreferredVisualization\x18\x08 \x01(\x0e\x32\x1c.grafanav3.FrameMeta.VisType\x12\x1b\n\x13\x65xecutedQueryString\x18\t \x01(\t\x1a\xf4\x02\n\x06Notice\x12<\n\x08Severity\x18\x01 \x01(\x0e\x32*.grafanav3.FrameMeta.Notice.NoticeSeverity\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\x12\x38\n\x07inspect\x18\x04 \x01(\x0e\x32\'.grafanav3.FrameMeta.Notice.InspectType\"\\\n\x0eNoticeSeverity\x12\x16\n\x12NoticeSeverityInfo\x10\x00\x12\x19\n\x15NoticeSeverityWarning\x10\x01\x12\x17\n\x13NoticeSeverityError\x10\x03\"x\n\x0bInspectType\x12\x13\n\x0fInspectTypeNone\x10\x00\x12\x13\n\x0fInspectTypeMeta\x10\x01\x12\x14\n\x10InspectTypeError\x10\x02\x12\x13\n\x0fInspectTypeData\x10\x03\x12\x14\n\x10InspectTypeStats\x10\x04\"\xab\x01\n\tFrameType\x12\x14\n\x10\x46rameTypeUnknown\x10\x00\x12\x1b\n\x17\x46rameTypeTimeSeriesWide\x10\x01\x12\x1b\n\x17\x46rameTypeTimeSeriesLong\x10\x02\x12\x1b\n\x17\x46rameTypeTimeSeriesMany\x10\x03\x12\x1d\n\x19\x46rameTypeDirectoryListing\x10\x04\x12\x12\n\x0e\x46rameTypeTable\x10\x05\"f\n\x07VisType\x12\x10\n\x0cVisTypeGraph\x10\x00\x12\x10\n\x0cVisTypeTable\x10\x01\x12\x0f\n\x0bVisTypeLogs\x10\x02\x12\x10\n\x0cVisTypeTrace\x10\x03\x12\x14\n\x10VisTypeNodeGraph\x10\x04\"]\n\x18ListDimensionKeysRequest\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x31\n\x13selected_dimensions\x18\x02 \x03(\x0b\x32\x14.grafanav3.Dimension\"\x85\x01\n\x19ListDimensionKeysResponse\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.grafanav3.ListDimensionKeysResponse.Result\x1a*\n\x06Result\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"v\n\x1aListDimensionValuesRequest\x12\x15\n\rdimension_key\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x31\n\x13selected_dimensions\x18\x03 \x03(\x0b\x32\x14.grafanav3.Dimension\"\x8b\x01\n\x1bListDimensionValuesResponse\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.grafanav3.ListDimensionValuesResponse.Result\x1a,\n\x06Result\x12\r\n\x05value\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"3\n\tTimeRange\x12\x13\n\x0b\x66romEpochMS\x18\x01 \x01(\x03\x12\x11\n\ttoEpochMS\x18\x02 \x01(\x03\"\'\n\tDimension\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xad\x01\n\x0cQueryRequest\x12\r\n\x05refId\x18\x01 \x01(\t\x12\x15\n\rmaxDataPoints\x18\x02 \x01(\x03\x12\x12\n\nintervalMS\x18\x03 \x01(\x03\x12\'\n\ttimeRange\x18\x04 \x01(\x0b\x32\x14.grafanav3.TimeRange\x12\x10\n\x08startKey\x18\x05 \x01(\x03\x12(\n\ndimensions\x18\x06 \x03(\x0b\x32\x14.grafanav3.Dimension\"\x8a\x01\n\rQueryResponse\x12\r\n\x05refId\x18\x01 \x01(\t\x12\x0f\n\x07nextKey\x18\x02 \x01(\x03\x12.\n\x06values\x18\x03 \x03(\x0b\x32\x1e.grafanav3.QueryResponse.Value\x1a)\n\x05Value\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x02*-\n\x0cTimeOrdering\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\x32\x9a\x05\n\x0fGrafanaQueryAPI\x12`\n\x11ListDimensionKeys\x12#.grafanav3.ListDimensionKeysRequest\x1a$.grafanav3.ListDimensionKeysResponse\"\x00\x12\x66\n\x13ListDimensionValues\x12%.grafanav3.ListDimensionValuesRequest\x1a&.grafanav3.ListDimensionValuesResponse\"\x00\x12N\n\x0bListMetrics\x12\x1d.grafanav3.ListMetricsRequest\x1a\x1e.grafanav3.ListMetricsResponse\"\x00\x12P\n\x0fGetQueryOptions\x12\x1c.grafanav3.GetOptionsRequest\x1a\x1d.grafanav3.GetOptionsResponse\"\x00\x12W\n\x0eGetMetricValue\x12 .grafanav3.GetMetricValueRequest\x1a!.grafanav3.GetMetricValueResponse\"\x00\x12]\n\x10GetMetricHistory\x12\".grafanav3.GetMetricHistoryRequest\x1a#.grafanav3.GetMetricHistoryResponse\"\x00\x12\x63\n\x12GetMetricAggregate\x12$.grafanav3.GetMetricAggregateRequest\x1a%.grafanav3.GetMetricAggregateResponse\"\x00\x42\x38Z6bitbucket.org/innius/grafana-simple-grpc-datasource/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.opah.grafana_apiv3_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6bitbucket.org/innius/grafana-simple-grpc-datasource/v3'
  _globals['_GETMETRICVALUEREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_GETMETRICVALUEREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETOPTIONSREQUEST_SELECTEDOPTIONSENTRY']._loaded_options = None
  _globals['_GETOPTIONSREQUEST_SELECTEDOPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETMETRICAGGREGATEREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_GETMETRICAGGREGATEREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETMETRICHISTORYREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_GETMETRICHISTORYREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_TIMEORDERING']._serialized_start=4748
  _globals['_TIMEORDERING']._serialized_end=4793
  _globals['_LISTMETRICSREQUEST']._serialized_start=92
  _globals['_LISTMETRICSREQUEST']._serialized_end=170
  _globals['_LISTMETRICSRESPONSE']._serialized_start=172
  _globals['_LISTMETRICSRESPONSE']._serialized_end=294
  _globals['_LISTMETRICSRESPONSE_METRIC']._serialized_start=251
  _globals['_LISTMETRICSRESPONSE_METRIC']._serialized_end=294
  _globals['_GETMETRICVALUEREQUEST']._serialized_start=297
  _globals['_GETMETRICVALUEREQUEST']._serialized_end=583
  _globals['_GETMETRICVALUEREQUEST_OPTIONSENTRY']._serialized_start=537
  _globals['_GETMETRICVALUEREQUEST_OPTIONSENTRY']._serialized_end=583
  _globals['_GETMETRICVALUERESPONSE']._serialized_start=586
  _globals['_GETMETRICVALUERESPONSE']._serialized_end=821
  _globals['_GETMETRICVALUERESPONSE_FRAME']._serialized_start=670
  _globals['_GETMETRICVALUERESPONSE_FRAME']._serialized_end=821
  _globals['_GETOPTIONSREQUEST']._serialized_start=824
  _globals['_GETOPTIONSREQUEST']._serialized_end=1113
  _globals['_GETOPTIONSREQUEST_SELECTEDOPTIONSENTRY']._serialized_start=980
  _globals['_GETOPTIONSREQUEST_SELECTEDOPTIONSENTRY']._serialized_end=1034
  _globals['_GETOPTIONSREQUEST_QUERYTYPE']._serialized_start=1036
  _globals['_GETOPTIONSREQUEST_QUERYTYPE']._serialized_end=1113
  _globals['_ENUMVALUE']._serialized_start=1115
  _globals['_ENUMVALUE']._serialized_end=1191
  _globals['_OPTION']._serialized_start=1194
  _globals['_OPTION']._serialized_end=1379
  _globals['_OPTION_TYPE']._serialized_start=1350
  _globals['_OPTION_TYPE']._serialized_end=1379
  _globals['_GETOPTIONSRESPONSE']._serialized_start=1381
  _globals['_GETOPTIONSRESPONSE']._serialized_end=1437
  _globals['_GETMETRICAGGREGATEREQUEST']._serialized_start=1440
  _globals['_GETMETRICAGGREGATEREQUEST']._serialized_end=1842
  _globals['_GETMETRICAGGREGATEREQUEST_OPTIONSENTRY']._serialized_start=537
  _globals['_GETMETRICAGGREGATEREQUEST_OPTIONSENTRY']._serialized_end=583
  _globals['_GETMETRICAGGREGATERESPONSE']._serialized_start=1844
  _globals['_GETMETRICAGGREGATERESPONSE']._serialized_end=1925
  _globals['_GETMETRICHISTORYREQUEST']._serialized_start=1928
  _globals['_GETMETRICHISTORYREQUEST']._serialized_end=2306
  _globals['_GETMETRICHISTORYREQUEST_OPTIONSENTRY']._serialized_start=537
  _globals['_GETMETRICHISTORYREQUEST_OPTIONSENTRY']._serialized_end=583
  _globals['_GETMETRICHISTORYRESPONSE']._serialized_start=2308
  _globals['_GETMETRICHISTORYRESPONSE']._serialized_end=2387
  _globals['_LABEL']._serialized_start=2389
  _globals['_LABEL']._serialized_end=2424
  _globals['_FIELD']._serialized_start=2427
  _globals['_FIELD']._serialized_end=2555
  _globals['_VALUEMAPPING']._serialized_start=2557
  _globals['_VALUEMAPPING']._serialized_end=2641
  _globals['_CONFIG']._serialized_start=2643
  _globals['_CONFIG']._serialized_end=2708
  _globals['_SINGLEVALUEFIELD']._serialized_start=2711
  _globals['_SINGLEVALUEFIELD']._serialized_end=2848
  _globals['_FRAME']._serialized_start=2851
  _globals['_FRAME']._serialized_end=2992
  _globals['_FRAMEMETA']._serialized_start=2995
  _globals['_FRAMEMETA']._serialized_end=3842
  _globals['_FRAMEMETA_NOTICE']._serialized_start=3192
  _globals['_FRAMEMETA_NOTICE']._serialized_end=3564
  _globals['_FRAMEMETA_NOTICE_NOTICESEVERITY']._serialized_start=3350
  _globals['_FRAMEMETA_NOTICE_NOTICESEVERITY']._serialized_end=3442
  _globals['_FRAMEMETA_NOTICE_INSPECTTYPE']._serialized_start=3444
  _globals['_FRAMEMETA_NOTICE_INSPECTTYPE']._serialized_end=3564
  _globals['_FRAMEMETA_FRAMETYPE']._serialized_start=3567
  _globals['_FRAMEMETA_FRAMETYPE']._serialized_end=3738
  _globals['_FRAMEMETA_VISTYPE']._serialized_start=3740
  _globals['_FRAMEMETA_VISTYPE']._serialized_end=3842
  _globals['_LISTDIMENSIONKEYSREQUEST']._serialized_start=3844
  _globals['_LISTDIMENSIONKEYSREQUEST']._serialized_end=3937
  _globals['_LISTDIMENSIONKEYSRESPONSE']._serialized_start=3940
  _globals['_LISTDIMENSIONKEYSRESPONSE']._serialized_end=4073
  _globals['_LISTDIMENSIONKEYSRESPONSE_RESULT']._serialized_start=4031
  _globals['_LISTDIMENSIONKEYSRESPONSE_RESULT']._serialized_end=4073
  _globals['_LISTDIMENSIONVALUESREQUEST']._serialized_start=4075
  _globals['_LISTDIMENSIONVALUESREQUEST']._serialized_end=4193
  _globals['_LISTDIMENSIONVALUESRESPONSE']._serialized_start=4196
  _globals['_LISTDIMENSIONVALUESRESPONSE']._serialized_end=4335
  _globals['_LISTDIMENSIONVALUESRESPONSE_RESULT']._serialized_start=4291
  _globals['_LISTDIMENSIONVALUESRESPONSE_RESULT']._serialized_end=4335
  _globals['_TIMERANGE']._serialized_start=4337
  _globals['_TIMERANGE']._serialized_end=4388
  _globals['_DIMENSION']._serialized_start=4390
  _globals['_DIMENSION']._serialized_end=4429
  _globals['_QUERYREQUEST']._serialized_start=4432
  _globals['_QUERYREQUEST']._serialized_end=4605
  _globals['_QUERYRESPONSE']._serialized_start=4608
  _globals['_QUERYRESPONSE']._serialized_end=4746
  _globals['_QUERYRESPONSE_VALUE']._serialized_start=4705
  _globals['_QUERYRESPONSE_VALUE']._serialized_end=4746
  _globals['_GRAFANAQUERYAPI']._serialized_start=4796
  _globals['_GRAFANAQUERYAPI']._serialized_end=5462
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from lofar_sid.interface.opah import grafana_apiv3_pb2 as lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in lofar_sid/interface/opah/grafana_apiv3_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class GrafanaQueryAPIStub(object):
    """The GrafanaQueryAPI definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDimensionKeys = channel.unary_unary(
                '/grafanav3.GrafanaQueryAPI/ListDimensionKeys',
                request_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionKeysRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionKeysResponse.FromString,
                _registered_method=True)
        self.ListDimensionValues = channel.unary_unary(
                '/grafanav3.GrafanaQueryAPI/ListDimensionValues',
                request_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionValuesRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionValuesResponse.FromString,
                _registered_method=True)
        self.ListMetrics = channel.unary_unary(
                '/grafanav3.GrafanaQueryAPI/ListMetrics',
                request_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListMetricsRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListMetricsResponse.FromString,
                _registered_method=True)
        self.GetQueryOptions = channel.unary_unary(
                '/grafanav3.GrafanaQueryAPI/GetQueryOptions',
                request_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetOptionsRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetOptionsResponse.FromString,
                _registered_method=True)
        self.GetMetricValue = channel.unary_unary(
                '/grafanav3.GrafanaQueryAPI/GetMetricValue',
                request_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricValueRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricValueResponse.FromString,
                _registered_method=True)
        self.GetMetricHistory = channel.unary_unary(
                '/grafanav3.GrafanaQueryAPI/GetMetricHistory',
                request_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricHistoryRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricHistoryResponse.FromString,
                _registered_method=True)
        self.GetMetricAggregate = channel.unary_unary(
                '/grafanav3.GrafanaQueryAPI/GetMetricAggregate',
                request_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricAggregateRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricAggregateResponse.FromString,
                _registered_method=True)


class GrafanaQueryAPIServicer(object):
    """The GrafanaQueryAPI definition.
    """

    def ListDimensionKeys(self, request, context):
        """Returns a list of all available dimensions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDimensionValues(self, request, context):
        """Returns a list of all dimension values for a certain dimension
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMetrics(self, request, context):
        """Returns all metrics from the system
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetQueryOptions(self, request, context):
        """Gets the options for the specified query type
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetricValue(self, request, context):
        """Gets the last known value for one or more metrics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetricHistory(self, request, context):
        """Gets the history for one or more metrics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetricAggregate(self, request, context):
        """Gets the history for one or more metrics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GrafanaQueryAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDimensionKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDimensionKeys,
                    request_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionKeysRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionKeysResponse.SerializeToString,
            ),
            'ListDimensionValues': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDimensionValues,
                    request_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionValuesRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionValuesResponse.SerializeToString,
            ),
            'ListMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMetrics,
                    request_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListMetricsRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListMetricsResponse.SerializeToString,
            ),
            'GetQueryOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetQueryOptions,
                    request_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetOptionsRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetOptionsResponse.SerializeToString,
            ),
            'GetMetricValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetricValue,
                    request_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricValueRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricValueResponse.SerializeToString,
            ),
            'GetMetricHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetricHistory,
                    request_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricHistoryRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricHistoryResponse.SerializeToString,
            ),
            'GetMetricAggregate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetricAggregate,
                    request_deserializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricAggregateRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricAggregateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'grafanav3.GrafanaQueryAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('grafanav3.GrafanaQueryAPI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class GrafanaQueryAPI(object):
    """The GrafanaQueryAPI definition.
    """

    @staticmethod
    def ListDimensionKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/grafanav3.GrafanaQueryAPI/ListDimensionKeys',
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionKeysRequest.SerializeToString,
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDimensionValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/grafanav3.GrafanaQueryAPI/ListDimensionValues',
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionValuesRequest.SerializeToString,
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListDimensionValuesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/grafanav3.GrafanaQueryAPI/ListMetrics',
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListMetricsRequest.SerializeToString,
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.ListMetricsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetQueryOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/grafanav3.GrafanaQueryAPI/GetQueryOptions',
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetOptionsRequest.SerializeToString,
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetOptionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMetricValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/grafanav3.GrafanaQueryAPI/GetMetricValue',
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricValueRequest.SerializeToString,
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricValueResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMetricHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/grafanav3.GrafanaQueryAPI/GetMetricHistory',
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricHistoryRequest.SerializeToString,
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMetricAggregate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/grafanav3.GrafanaQueryAPI/GetMetricAggregate',
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricAggregateRequest.SerializeToString,
            lofar__sid_dot_interface_dot_opah_dot_grafana__apiv3__pb2.GetMetricAggregateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class StartObservationRequest(_message.Message):
    __slots__ = ("configuration",)
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    configuration: str
    def __init__(self, configuration: _Optional[str] = ...) -> None: ...

class StopObservationRequest(_message.Message):
    __slots__ = ("observation_id",)
    OBSERVATION_ID_FIELD_NUMBER: _ClassVar[int]
    observation_id: int
    def __init__(self, observation_id: _Optional[int] = ...) -> None: ...

class ObservationReply(_message.Message):
    __slots__ = ("success", "exception")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    EXCEPTION_FIELD_NUMBER: _ClassVar[int]
    success: bool
    exception: str
    def __init__(self, success: bool = ..., exception: _Optional[str] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FrequencyBand(_message.Message):
    __slots__ = ("antenna_type", "clock", "nyquist_zone")
    ANTENNA_TYPE_FIELD_NUMBER: _ClassVar[int]
    CLOCK_FIELD_NUMBER: _ClassVar[int]
    NYQUIST_ZONE_FIELD_NUMBER: _ClassVar[int]
    antenna_type: str
    clock: int
    nyquist_zone: int
    def __init__(self, antenna_type: _Optional[str] = ..., clock: _Optional[int] = ..., nyquist_zone: _Optional[int] = ...) -> None: ...

class BstRequest(_message.Message):
    __slots__ = ("antenna_field", "maxage")
    ANTENNA_FIELD_FIELD_NUMBER: _ClassVar[int]
    MAXAGE_FIELD_NUMBER: _ClassVar[int]
    antenna_field: str
    maxage: int
    def __init__(self, antenna_field: _Optional[str] = ..., maxage: _Optional[int] = ...) -> None: ...

class BstResult(_message.Message):
    __slots__ = ("timestamp", "frequency_band", "integration_interval", "beamlets")
    class BstBeamlet(_message.Message):
        __slots__ = ("beamlet", "x_power_db", "y_power_db")
        BEAMLET_FIELD_NUMBER: _ClassVar[int]
        X_POWER_DB_FIELD_NUMBER: _ClassVar[int]
        Y_POWER_DB_FIELD_NUMBER: _ClassVar[int]
        beamlet: int
        x_power_db: float
        y_power_db: float
        def __init__(self, beamlet: _Optional[int] = ..., x_power_db: _Optional[float] = ..., y_power_db: _Optional[float] = ...) -> None: ...
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    FREQUENCY_BAND_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    BEAMLETS_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    frequency_band: FrequencyBand
    integration_interval: float
    beamlets: _containers.RepeatedCompositeFieldContainer[BstResult.BstBeamlet]
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., frequency_band: _Optional[_Union[FrequencyBand, _Mapping]] = ..., integration_interval: _Optional[float] = ..., beamlets: _Optional[_Iterable[_Union[BstResult.BstBeamlet, _Mapping]]] = ...) -> None: ...

class BstReply(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: BstResult
    def __init__(self, result: _Optional[_Union[BstResult, _Mapping]] = ...) -> None: ...

class SstRequest(_message.Message):
    __slots__ = ("antenna_field", "maxage")
    ANTENNA_FIELD_FIELD_NUMBER: _ClassVar[int]
    MAXAGE_FIELD_NUMBER: _ClassVar[int]
    antenna_field: str
    maxage: int
    def __init__(self, antenna_field: _Optional[str] = ..., maxage: _Optional[int] = ...) -> None: ...

class SstResult(_message.Message):
    __slots__ = ("timestamp", "frequency_band", "integration_interval", "subbands")
    class SstSubband(_message.Message):
        __slots__ = ("subband", "frequency", "antennas")
        class SstAntenna(_message.Message):
            __slots__ = ("antenna", "x_power_db", "y_power_db")
            ANTENNA_FIELD_NUMBER: _ClassVar[int]
            X_POWER_DB_FIELD_NUMBER: _ClassVar[int]
            Y_POWER_DB_FIELD_NUMBER: _ClassVar[int]
            antenna: int
            x_power_db: float
            y_power_db: float
            def __init__(self, antenna: _Optional[int] = ..., x_power_db: _Optional[float] = ..., y_power_db: _Optional[float] = ...) -> None: ...
        SUBBAND_FIELD_NUMBER: _ClassVar[int]
        FREQUENCY_FIELD_NUMBER: _ClassVar[int]
        ANTENNAS_FIELD_NUMBER: _ClassVar[int]
        subband: int
        frequency: float
        antennas: _containers.RepeatedCompositeFieldContainer[SstResult.SstSubband.SstAntenna]
        def __init__(self, subband: _Optional[int] = ..., frequency: _Optional[float] = ..., antennas: _Optional[_Iterable[_Union[SstResult.SstSubband.SstAntenna, _Mapping]]] = ...) -> None: ...
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    FREQUENCY_BAND_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    SUBBANDS_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    frequency_band: FrequencyBand
    integration_interval: float
    subbands: _containers.RepeatedCompositeFieldContainer[SstResult.SstSubband]
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., frequency_band: _Optional[_Union[FrequencyBand, _Mapping]] = ..., integration_interval: _Optional[float] = ..., subbands: _Optional[_Iterable[_Union[SstResult.SstSubband, _Mapping]]] = ...) -> None: ...

class SstReply(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: SstResult
    def __init__(self, result: _Optional[_Union[SstResult, _Mapping]] = ...) -> None: ...

class XstRequest(_message.Message):
    __slots__ = ("antenna_field", "maxage")
    ANTENNA_FIELD_FIELD_NUMBER: _ClassVar[int]
    MAXAGE_FIELD_NUMBER: _ClassVar[int]
    antenna_field: str
    maxage: int
    def __init__(self, antenna_field: _Optional[str] = ..., maxage: _Optional[int] = ...) -> None: ...

class XstResult(_message.Message):
    __slots__ = ("timestamp", "frequency_band", "integration_interval", "subband", "frequency", "baselines")
    class XstBaseline(_message.Message):
        __slots__ = ("antenna1", "antenna2", "xx", "xy", "yx", "yy")
        class XstValue(_message.Message):
            __slots__ = ("power_db", "phase")
            POWER_DB_FIELD_NUMBER: _ClassVar[int]
            PHASE_FIELD_NUMBER: _ClassVar[int]
            power_db: float
            phase: float
            def __init__(self, power_db: _Optional[float] = ..., phase: _Optional[float] = ...) -> None: ...
        ANTENNA1_FIELD_NUMBER: _ClassVar[int]
        ANTENNA2_FIELD_NUMBER: _ClassVar[int]
        XX_FIELD_NUMBER: _ClassVar[int]
        XY_FIELD_NUMBER: _ClassVar[int]
        YX_FIELD_NUMBER: _ClassVar[int]
        YY_FIELD_NUMBER: _ClassVar[int]
        antenna1: int
        antenna2: int
        xx: XstResult.XstBaseline.XstValue
        xy: XstResult.XstBaseline.XstValue
        yx: XstResult.XstBaseline.XstValue
        yy: XstResult.XstBaseline.XstValue
        def __init__(self, antenna1: _Optional[int] = ..., antenna2: _Optional[int] = ..., xx: _Optional[_Union[XstResult.XstBaseline.XstValue, _Mapping]] = ..., xy: _Optional[_Union[XstResult.XstBaseline.XstValue, _Mapping]] = ..., yx: _Optional[_Union[XstResult.XstBaseline.XstValue, _Mapping]] = ..., yy: _Optional[_Union[XstResult.XstBaseline.XstValue, _Mapping]] = ...) -> None: ...
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    FREQUENCY_BAND_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    SUBBAND_FIELD_NUMBER: _ClassVar[int]
    FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    BASELINES_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    frequency_band: FrequencyBand
    integration_interval: float
    subband: int
    frequency: float
    baselines: _containers.RepeatedCompositeFieldContainer[XstResult.XstBaseline]
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., frequency_band: _Optional[_Union[FrequencyBand, _Mapping]] = ..., integration_interval: _Optional[float] = ..., subband: _Optional[int] = ..., frequency: _Optional[float] = ..., baselines: _Optional[_Iterable[_Union[XstResult.XstBaseline, _Mapping]]] = ...) -> None: ...

class XstReply(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: XstResult
    def __init__(self, result: _Optional[_Union[XstResult, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TimeOrdering(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ASCENDING: _ClassVar[TimeOrdering]
    DESCENDING: _ClassVar[TimeOrdering]
ASCENDING: TimeOrdering
DESCENDING: TimeOrdering

class ListMetricsRequest(_message.Message):
    __slots__ = ("dimensions", "filter")
    DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    dimensions: _containers.RepeatedCompositeFieldContainer[Dimension]
    filter: str
    def __init__(self, dimensions: _Optional[_Iterable[_Union[Dimension, _Mapping]]] = ..., filter: _Optional[str] = ...) -> None: ...

class ListMetricsResponse(_message.Message):
    __slots__ = ("Metrics",)
    class Metric(_message.Message):
        __slots__ = ("name", "description")
        NAME_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        name: str
        description: str
        def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...
    METRICS_FIELD_NUMBER: _ClassVar[int]
    Metrics: _containers.RepeatedCompositeFieldContainer[ListMetricsResponse.Metric]
    def __init__(self, Metrics: _Optional[_Iterable[_Union[ListMetricsResponse.Metric, _Mapping]]] = ...) -> None: ...

class GetMetricValueRequest(_message.Message):
    __slots__ = ("dimensions", "metrics", "options", "startDate", "endDate")
    class OptionsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    STARTDATE_FIELD_NUMBER: _ClassVar[int]
    ENDDATE_FIELD_NUMBER: _ClassVar[int]
    dimensions: _containers.RepeatedCompositeFieldContainer[Dimension]
    metrics: _containers.RepeatedScalarFieldContainer[str]
    options: _containers.ScalarMap[str, str]
    startDate: _timestamp_pb2.Timestamp
    endDate: _timestamp_pb2.Timestamp
    def __init__(self, dimensions: _Optional[_Iterable[_Union[Dimension, _Mapping]]] = ..., metrics: _Optional[_Iterable[str]] = ..., options: _Optional[_Mapping[str, str]] = ..., startDate: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., endDate: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetMetricValueResponse(_message.Message):
    __slots__ = ("frames",)
    class Frame(_message.Message):
        __slots__ = ("metric", "timestamp", "fields", "meta")
        METRIC_FIELD_NUMBER: _ClassVar[int]
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        META_FIELD_NUMBER: _ClassVar[int]
        metric: str
        timestamp: _timestamp_pb2.Timestamp
        fields: _containers.RepeatedCompositeFieldContainer[SingleValueField]
        meta: FrameMeta
        def __init__(self, metric: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., fields: _Optional[_Iterable[_Union[SingleValueField, _Mapping]]] = ..., meta: _Optional[_Union[FrameMeta, _Mapping]] = ...) -> None: ...
    FRAMES_FIELD_NUMBER: _ClassVar[int]
    frames: _containers.RepeatedCompositeFieldContainer[GetMetricValueResponse.Frame]
    def __init__(self, frames: _Optional[_Iterable[_Union[GetMetricValueResponse.Frame, _Mapping]]] = ...) -> None: ...

class GetOptionsRequest(_message.Message):
    __slots__ = ("queryType", "selectedOptions")
    class QueryType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        GetMetricHistory: _ClassVar[GetOptionsRequest.QueryType]
        GetMetricValue: _ClassVar[GetOptionsRequest.QueryType]
        GetMetricAggregate: _ClassVar[GetOptionsRequest.QueryType]
    GetMetricHistory: GetOptionsRequest.QueryType
    GetMetricValue: GetOptionsRequest.QueryType
    GetMetricAggregate: GetOptionsRequest.QueryType
    class SelectedOptionsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    QUERYTYPE_FIELD_NUMBER: _ClassVar[int]
    SELECTEDOPTIONS_FIELD_NUMBER: _ClassVar[int]
    queryType: GetOptionsRequest.QueryType
    selectedOptions: _containers.ScalarMap[str, str]
    def __init__(self, queryType: _Optional[_Union[GetOptionsRequest.QueryType, str]] = ..., selectedOptions: _Optional[_Mapping[str, str]] = ...) -> None: ...

class EnumValue(_message.Message):
    __slots__ = ("id", "description", "label", "default")
    ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    id: str
    description: str
    label: str
    default: bool
    def __init__(self, id: _Optional[str] = ..., description: _Optional[str] = ..., label: _Optional[str] = ..., default: bool = ...) -> None: ...

class Option(_message.Message):
    __slots__ = ("id", "description", "type", "enumValues", "required", "label")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        Enum: _ClassVar[Option.Type]
        Boolean: _ClassVar[Option.Type]
    Enum: Option.Type
    Boolean: Option.Type
    ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ENUMVALUES_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    id: str
    description: str
    type: Option.Type
    enumValues: _containers.RepeatedCompositeFieldContainer[EnumValue]
    required: bool
    label: str
    def __init__(self, id: _Optional[str] = ..., description: _Optional[str] = ..., type: _Optional[_Union[Option.Type, str]] = ..., enumValues: _Optional[_Iterable[_Union[EnumValue, _Mapping]]] = ..., required: bool = ..., label: _Optional[str] = ...) -> None: ...

class GetOptionsResponse(_message.Message):
    __slots__ = ("options",)
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    options: _containers.RepeatedCompositeFieldContainer[Option]
    def __init__(self, options: _Optional[_Iterable[_Union[Option, _Mapping]]] = ...) -> None: ...

class GetMetricAggregateRequest(_message.Message):
    __slots__ = ("dimensions", "metrics", "startDate", "endDate", "maxItems", "timeOrdering", "startingToken", "intervalMs", "options")
    class OptionsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    STARTDATE_FIELD_NUMBER: _ClassVar[int]
    ENDDATE_FIELD_NUMBER: _ClassVar[int]
    MAXITEMS_FIELD_NUMBER: _ClassVar[int]
    TIMEORDERING_FIELD_NUMBER: _ClassVar[int]
    STARTINGTOKEN_FIELD_NUMBER: _ClassVar[int]
    INTERVALMS_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    dimensions: _containers.RepeatedCompositeFieldContainer[Dimension]
    metrics: _containers.RepeatedScalarFieldContainer[str]
    startDate: _timestamp_pb2.Timestamp
    endDate: _timestamp_pb2.Timestamp
    maxItems: int
    timeOrdering: TimeOrdering
    startingToken: str
    intervalMs: int
    options: _containers.ScalarMap[str, str]
    def __init__(self, dimensions: _Optional[_Iterable[_Union[Dimension, _Mapping]]] = ..., metrics: _Optional[_Iterable[str]] = ..., startDate: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., endDate: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., maxItems: _Optional[int] = ..., timeOrdering: _Optional[_Union[TimeOrdering, str]] = ..., startingToken: _Optional[str] = ..., intervalMs: _Optional[int] = ..., options: _Optional[_Mapping[str, str]] = ...) -> None: ...

class GetMetricAggregateResponse(_message.Message):
    __slots__ = ("frames", "nextToken")
    FRAMES_FIELD_NUMBER: _ClassVar[int]
    NEXTTOKEN_FIELD_NUMBER: _ClassVar[int]
    frames: _containers.RepeatedCompositeFieldContainer[Frame]
    nextToken: str
    def __init__(self, frames: _Optional[_Iterable[_Union[Frame, _Mapping]]] = ..., nextToken: _Optional[str] = ...) -> None: ...

class GetMetricHistoryRequest(_message.Message):
    __slots__ = ("dimensions", "metrics", "startDate", "endDate", "maxItems", "timeOrdering", "startingToken", "options")
    class OptionsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    STARTDATE_FIELD_NUMBER: _ClassVar[int]
    ENDDATE_FIELD_NUMBER: _ClassVar[int]
    MAXITEMS_FIELD_NUMBER: _ClassVar[int]
    TIMEORDERING_FIELD_NUMBER: _ClassVar[int]
    STARTINGTOKEN_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    dimensions: _containers.RepeatedCompositeFieldContainer[Dimension]
    metrics: _containers.RepeatedScalarFieldContainer[str]
    startDate: _timestamp_pb2.Timestamp
    endDate: _timestamp_pb2.Timestamp
    maxItems: int
    timeOrdering: TimeOrdering
    startingToken: str
    options: _containers.ScalarMap[str, str]
    def __init__(self, dimensions: _Optional[_Iterable[_Union[Dimension, _Mapping]]] = ..., metrics: _Optional[_Iterable[str]] = ..., startDate: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., endDate: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., maxItems: _Optional[int] = ..., timeOrdering: _Optional[_Union[TimeOrdering, str]] = ..., startingToken: _Optional[str] = ..., options: _Optional[_Mapping[str, str]] = ...) -> None: ...

class GetMetricHistoryResponse(_message.Message):
    __slots__ = ("frames", "nextToken")
    FRAMES_FIELD_NUMBER: _ClassVar[int]
    NEXTTOKEN_FIELD_NUMBER: _ClassVar[int]
    frames: _containers.RepeatedCompositeFieldContainer[Frame]
    nextToken: str
    def __init__(self, frames: _Optional[_Iterable[_Union[Frame, _Mapping]]] = ..., nextToken: _Optional[str] = ...) -> None: ...

class Label(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class Field(_message.Message):
    __slots__ = ("name", "labels", "config", "values", "stringValues")
    NAME_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    STRINGVALUES_FIELD_NUMBER: _ClassVar[int]
    name: str
    labels: _containers.RepeatedCompositeFieldContainer[Label]
    config: config
    values: _containers.RepeatedScalarFieldContainer[float]
    stringValues: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[Label, _Mapping]]] = ..., config: _Optional[_Union[config, _Mapping]] = ..., values: _Optional[_Iterable[float]] = ..., stringValues: _Optional[_Iterable[str]] = ...) -> None: ...

class ValueMapping(_message.Message):
    __slots__ = ("to", "value", "text", "color")
    FROM_FIELD_NUMBER: _ClassVar[int]
    TO_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    to: float
    value: str
    text: str
    color: str
    def __init__(self, to: _Optional[float] = ..., value: _Optional[str] = ..., text: _Optional[str] = ..., color: _Optional[str] = ..., **kwargs) -> None: ...

class config(_message.Message):
    __slots__ = ("unit", "Mappings")
    UNIT_FIELD_NUMBER: _ClassVar[int]
    MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    unit: str
    Mappings: _containers.RepeatedCompositeFieldContainer[ValueMapping]
    def __init__(self, unit: _Optional[str] = ..., Mappings: _Optional[_Iterable[_Union[ValueMapping, _Mapping]]] = ...) -> None: ...

class SingleValueField(_message.Message):
    __slots__ = ("name", "labels", "config", "value", "stringValue")
    NAME_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    STRINGVALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    labels: _containers.RepeatedCompositeFieldContainer[Label]
    config: config
    value: float
    stringValue: str
    def __init__(self, name: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[Label, _Mapping]]] = ..., config: _Optional[_Union[config, _Mapping]] = ..., value: _Optional[float] = ..., stringValue: _Optional[str] = ...) -> None: ...

class Frame(_message.Message):
    __slots__ = ("metric", "timestamps", "fields", "meta")
    METRIC_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMPS_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    metric: str
    timestamps: _containers.RepeatedCompositeFieldContainer[_timestamp_pb2.Timestamp]
    fields: _containers.RepeatedCompositeFieldContainer[Field]
    meta: FrameMeta
    def __init__(self, metric: _Optional[str] = ..., timestamps: _Optional[_Iterable[_Union[_timestamp_pb2.Timestamp, _Mapping]]] = ..., fields: _Optional[_Iterable[_Union[Field, _Mapping]]] = ..., meta: _Optional[_Union[FrameMeta, _Mapping]] = ...) -> None: ...

class FrameMeta(_message.Message):
    __slots__ = ("type", "Notices", "PreferredVisualization", "executedQueryString")
    class FrameType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FrameTypeUnknown: _ClassVar[FrameMeta.FrameType]
        FrameTypeTimeSeriesWide: _ClassVar[FrameMeta.FrameType]
        FrameTypeTimeSeriesLong: _ClassVar[FrameMeta.FrameType]
        FrameTypeTimeSeriesMany: _ClassVar[FrameMeta.FrameType]
        FrameTypeDirectoryListing: _ClassVar[FrameMeta.FrameType]
        FrameTypeTable: _ClassVar[FrameMeta.FrameType]
    FrameTypeUnknown: FrameMeta.FrameType
    FrameTypeTimeSeriesWide: FrameMeta.FrameType
    FrameTypeTimeSeriesLong: FrameMeta.FrameType
    FrameTypeTimeSeriesMany: FrameMeta.FrameType
    FrameTypeDirectoryListing: FrameMeta.FrameType
    FrameTypeTable: FrameMeta.FrameType
    class VisType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VisTypeGraph: _ClassVar[FrameMeta.VisType]
        VisTypeTable: _ClassVar[FrameMeta.VisType]
        VisTypeLogs: _ClassVar[FrameMeta.VisType]
        VisTypeTrace: _ClassVar[FrameMeta.VisType]
        VisTypeNodeGraph: _ClassVar[FrameMeta.VisType]
    VisTypeGraph: FrameMeta.VisType
    VisTypeTable: FrameMeta.VisType
    VisTypeLogs: FrameMeta.VisType
    VisTypeTrace: FrameMeta.VisType
    VisTypeNodeGraph: FrameMeta.VisType
    class Notice(_message.Message):
        __slots__ = ("Severity", "text", "link", "inspect")
        class NoticeSeverity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            NoticeSeverityInfo: _ClassVar[FrameMeta.Notice.NoticeSeverity]
            NoticeSeverityWarning: _ClassVar[FrameMeta.Notice.NoticeSeverity]
            NoticeSeverityError: _ClassVar[FrameMeta.Notice.NoticeSeverity]
        NoticeSeverityInfo: FrameMeta.Notice.NoticeSeverity
        NoticeSeverityWarning: FrameMeta.Notice.NoticeSeverity
        NoticeSeverityError: FrameMeta.Notice.NoticeSeverity
        class InspectType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            InspectTypeNone: _ClassVar[FrameMeta.Notice.InspectType]
            InspectTypeMeta: _ClassVar[FrameMeta.Notice.InspectType]
            InspectTypeError: _ClassVar[FrameMeta.Notice.InspectType]
            InspectTypeData: _ClassVar[FrameMeta.Notice.InspectType]
            InspectTypeStats: _ClassVar[FrameMeta.Notice.InspectType]
        InspectTypeNone: FrameMeta.Notice.InspectType
        InspectTypeMeta: FrameMeta.Notice.InspectType
        InspectTypeError: FrameMeta.Notice.InspectType
        InspectTypeData: FrameMeta.Notice.InspectType
        InspectTypeStats: FrameMeta.Notice.InspectType
        SEVERITY_FIELD_NUMBER: _ClassVar[int]
        TEXT_FIELD_NUMBER: _ClassVar[int]
        LINK_FIELD_NUMBER: _ClassVar[int]
        INSPECT_FIELD_NUMBER: _ClassVar[int]
        Severity: FrameMeta.Notice.NoticeSeverity
        text: str
        link: str
        inspect: FrameMeta.Notice.InspectType
        def __init__(self, Severity: _Optional[_Union[FrameMeta.Notice.NoticeSeverity, str]] = ..., text: _Optional[str] = ..., link: _Optional[str] = ..., inspect: _Optional[_Union[FrameMeta.Notice.InspectType, str]] = ...) -> None: ...
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NOTICES_FIELD_NUMBER: _ClassVar[int]
    PREFERREDVISUALIZATION_FIELD_NUMBER: _ClassVar[int]
    EXECUTEDQUERYSTRING_FIELD_NUMBER: _ClassVar[int]
    type: FrameMeta.FrameType
    Notices: _containers.RepeatedCompositeFieldContainer[FrameMeta.Notice]
    PreferredVisualization: FrameMeta.VisType
    executedQueryString: str
    def __init__(self, type: _Optional[_Union[FrameMeta.FrameType, str]] = ..., Notices: _Optional[_Iterable[_Union[FrameMeta.Notice, _Mapping]]] = ..., PreferredVisualization: _Optional[_Union[FrameMeta.VisType, str]] = ..., executedQueryString: _Optional[str] = ...) -> None: ...

class ListDimensionKeysRequest(_message.Message):
    __slots__ = ("filter", "selected_dimensions")
    FILTER_FIELD_NUMBER: _ClassVar[int]
    SELECTED_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    filter: str
    selected_dimensions: _containers.RepeatedCompositeFieldContainer[Dimension]
    def __init__(self, filter: _Optional[str] = ..., selected_dimensions: _Optional[_Iterable[_Union[Dimension, _Mapping]]] = ...) -> None: ...

class ListDimensionKeysResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("key", "description")
        KEY_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        key: str
        description: str
        def __init__(self, key: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListDimensionKeysResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListDimensionKeysResponse.Result, _Mapping]]] = ...) -> None: ...

class ListDimensionValuesRequest(_message.Message):
    __slots__ = ("dimension_key", "filter", "selected_dimensions")
    DIMENSION_KEY_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    SELECTED_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    dimension_key: str
    filter: str
    selected_dimensions: _containers.RepeatedCompositeFieldContainer[Dimension]
    def __init__(self, dimension_key: _Optional[str] = ..., filter: _Optional[str] = ..., selected_dimensions: _Optional[_Iterable[_Union[Dimension, _Mapping]]] = ...) -> None: ...

class ListDimensionValuesResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("value", "description")
        VALUE_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        value: str
        description: str
        def __init__(self, value: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListDimensionValuesResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListDimensionValuesResponse.Result, _Mapping]]] = ...) -> None: ...

class TimeRange(_message.Message):
    __slots__ = ("fromEpochMS", "toEpochMS")
    FROMEPOCHMS_FIELD_NUMBER: _ClassVar[int]
    TOEPOCHMS_FIELD_NUMBER: _ClassVar[int]
    fromEpochMS: int
    toEpochMS: int
    def __init__(self, fromEpochMS: _Optional[int] = ..., toEpochMS: _Optional[int] = ...) -> None: ...

class Dimension(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class QueryRequest(_message.Message):
    __slots__ = ("refId", "maxDataPoints", "intervalMS", "timeRange", "startKey", "dimensions")
    REFID_FIELD_NUMBER: _ClassVar[int]
    MAXDATAPOINTS_FIELD_NUMBER: _ClassVar[int]
    INTERVALMS_FIELD_NUMBER: _ClassVar[int]
    TIMERANGE_FIELD_NUMBER: _ClassVar[int]
    STARTKEY_FIELD_NUMBER: _ClassVar[int]
    DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    refId: str
    maxDataPoints: int
    intervalMS: int
    timeRange: TimeRange
    startKey: int
    dimensions: _containers.RepeatedCompositeFieldContainer[Dimension]
    def __init__(self, refId: _Optional[str] = ..., maxDataPoints: _Optional[int] = ..., intervalMS: _Optional[int] = ..., timeRange: _Optional[_Union[TimeRange, _Mapping]] = ..., startKey: _Optional[int] = ..., dimensions: _Optional[_Iterable[_Union[Dimension, _Mapping]]] = ...) -> None: ...

class QueryResponse(_message.Message):
    __slots__ = ("refId", "nextKey", "values")
    class Value(_message.Message):
        __slots__ = ("timestamp", "value")
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        timestamp: int
        value: float
        def __init__(self, timestamp: _Optional[int] = ..., value: _Optional[float] = ...) -> None: ...
    REFID_FIELD_NUMBER: _ClassVar[int]
    NEXTKEY_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    refId: str
    nextKey: int
    values: _containers.RepeatedCompositeFieldContainer[QueryResponse.Value]
    def __init__(self, refId: _Optional[str] = ..., nextKey: _Optional[int] = ..., values: _Optional[_Iterable[_Union[QueryResponse.Value, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Station_State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OFF: _ClassVar[Station_State]
    HIBERNATE: _ClassVar[Station_State]
    STANDBY: _ClassVar[Station_State]
    ON: _ClassVar[Station_State]
OFF: Station_State
HIBERNATE: Station_State
STANDBY: Station_State
ON: Station_State

class SetStationStateRequest(_message.Message):
    __slots__ = ("station_state",)
    STATION_STATE_FIELD_NUMBER: _ClassVar[int]
    station_state: Station_State
    def __init__(self, station_state: _Optional[_Union[Station_State, str]] = ...) -> None: ...

class GetStationStateRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SoftStationResetRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class HardStationResetRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class StationStateResult(_message.Message):
    __slots__ = ("station_state",)
    STATION_STATE_FIELD_NUMBER: _ClassVar[int]
    station_state: Station_State
    def __init__(self, station_state: _Optional[_Union[Station_State, str]] = ...) -> None: ...

class StationStateReply(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: StationStateResult
    def __init__(self, result: _Optional[_Union[StationStateResult, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Antennafield_Power_Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    Antennafield_POWER_OFF: _ClassVar[Antennafield_Power_Status]
    Antennafield_POWER_ON: _ClassVar[Antennafield_Power_Status]
Antennafield_POWER_OFF: Antennafield_Power_Status
Antennafield_POWER_ON: Antennafield_Power_Status

class AntennafieldIdentifier(_message.Message):
    __slots__ = ("antenna_field_id",)
    ANTENNA_FIELD_ID_FIELD_NUMBER: _ClassVar[int]
    antenna_field_id: str
    def __init__(self, antenna_field_id: _Optional[str] = ...) -> None: ...

class SetAntennafieldRequest(_message.Message):
    __slots__ = ("identifier", "power_status")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    POWER_STATUS_FIELD_NUMBER: _ClassVar[int]
    identifier: AntennafieldIdentifier
    power_status: Antennafield_Power_Status
    def __init__(self, identifier: _Optional[_Union[AntennafieldIdentifier, _Mapping]] = ..., power_status: _Optional[_Union[Antennafield_Power_Status, str]] = ...) -> None: ...

class GetAntennafieldRequest(_message.Message):
    __slots__ = ("identifier",)
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    identifier: AntennafieldIdentifier
    def __init__(self, identifier: _Optional[_Union[AntennafieldIdentifier, _Mapping]] = ...) -> None: ...

class AntennafieldResult(_message.Message):
    __slots__ = ("identifier", "power_status")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    POWER_STATUS_FIELD_NUMBER: _ClassVar[int]
    identifier: AntennafieldIdentifier
    power_status: Antennafield_Power_Status
    def __init__(self, identifier: _Optional[_Union[AntennafieldIdentifier, _Mapping]] = ..., power_status: _Optional[_Union[Antennafield_Power_Status, str]] = ...) -> None: ...

class AntennafieldReply(_message.Message):
    __slots__ = ("success", "exception", "result")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    EXCEPTION_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    exception: str
    result: AntennafieldResult
    def __init__(self, success: bool = ..., exception: _Optional[str] = ..., result: _Optional[_Union[AntennafieldResult, _Mapping]] = ...) -> None: ...



#  Copyright (C) 2023 ASTRON (Netherlands Institute for Radio Astronomy)
#  SPDX-License-Identifier: Apache-2.0

"""Just the version"""


def about():
    """Return"""
    return "This is the Lofar SID interface library"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/station.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/station.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0lofar_sid/interface/stationcontrol/station.proto\x12\x17station_control.station\"W\n\x16SetStationStateRequest\x12=\n\rstation_state\x18\x01 \x01(\x0e\x32&.station_control.station.Station_State\"\x18\n\x16GetStationStateRequest\"\x19\n\x17SoftStationResetRequest\"\x19\n\x17HardStationResetRequest\"S\n\x12StationStateResult\x12=\n\rstation_state\x18\x01 \x01(\x0e\x32&.station_control.station.Station_State\"P\n\x11StationStateReply\x12;\n\x06result\x18\x01 \x01(\x0b\x32+.station_control.station.StationStateResult*<\n\rStation_State\x12\x07\n\x03OFF\x10\x00\x12\r\n\tHIBERNATE\x10\x01\x12\x0b\n\x07STANDBY\x10\x02\x12\x06\n\x02ON\x10\x03\x32\xdb\x03\n\x07Station\x12p\n\x0fGetStationState\x12/.station_control.station.GetStationStateRequest\x1a*.station_control.station.StationStateReply\"\x00\x12r\n\x0fSetStationState\x12/.station_control.station.SetStationStateRequest\x1a*.station_control.station.StationStateReply\"\x00\x30\x01\x12t\n\x10SoftStationReset\x12\x30.station_control.station.SoftStationResetRequest\x1a*.station_control.station.StationStateReply\"\x00\x30\x01\x12t\n\x10HardStationReset\x12\x30.station_control.station.HardStationResetRequest\x1a*.station_control.station.StationStateReply\"\x00\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.station_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STATION_STATE']._serialized_start=413
  _globals['_STATION_STATE']._serialized_end=473
  _globals['_SETSTATIONSTATEREQUEST']._serialized_start=77
  _globals['_SETSTATIONSTATEREQUEST']._serialized_end=164
  _globals['_GETSTATIONSTATEREQUEST']._serialized_start=166
  _globals['_GETSTATIONSTATEREQUEST']._serialized_end=190
  _globals['_SOFTSTATIONRESETREQUEST']._serialized_start=192
  _globals['_SOFTSTATIONRESETREQUEST']._serialized_end=217
  _globals['_HARDSTATIONRESETREQUEST']._serialized_start=219
  _globals['_HARDSTATIONRESETREQUEST']._serialized_end=244
  _globals['_STATIONSTATERESULT']._serialized_start=246
  _globals['_STATIONSTATERESULT']._serialized_end=329
  _globals['_STATIONSTATEREPLY']._serialized_start=331
  _globals['_STATIONSTATEREPLY']._serialized_end=411
  _globals['_STATION']._serialized_start=476
  _globals['_STATION']._serialized_end=951
# @@protoc_insertion_point(module_scope)
